==> knative-model-4.7.2-sources.jar: io/fabric8/knative/duck/v1alpha1/AddressableFluent.java <==
package io.fabric8.knative.duck.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.knative.v1.URLFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.v1.URL;
import io.fabric8.knative.v1.URLBuilder;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface AddressableFluent<A extends io.fabric8.knative.duck.v1alpha1.AddressableFluent<A>> extends Fluent<A>{


    public String getHostname();
    public A withHostname(String hostname);
    public Boolean hasHostname();
    public A withNewHostname(String arg1);
    public A withNewHostname(StringBuilder arg1);
    public A withNewHostname(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildUrl instead.
 * @return The buildable object.
 */
@Deprecated public URL getUrl();
    public URL buildUrl();
    public A withUrl(URL url);
    public Boolean hasUrl();
    public AddressableFluent.UrlNested<A> withNewUrl();
    public AddressableFluent.UrlNested<A> withNewUrlLike(URL item);
    public AddressableFluent.UrlNested<A> editUrl();
    public AddressableFluent.UrlNested<A> editOrNewUrl();
    public AddressableFluent.UrlNested<A> editOrNewUrlLike(URL item);

    public interface UrlNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,URLFluent<AddressableFluent.UrlNested<N>>{

        
    public N and();    public N endUrl();
}


}

==> knative-model-4.9.0-sources.jar: io/fabric8/knative/duck/v1alpha1/AddressableFluent.java <==
package io.fabric8.knative.duck.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.knative.v1.URLFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.v1.URL;
import io.fabric8.knative.v1.URLBuilder;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface AddressableFluent<A extends io.fabric8.knative.duck.v1alpha1.AddressableFluent<A>> extends Fluent<A>{


    public String getHostname();
    public A withHostname(String hostname);
    public Boolean hasHostname();
    public A withNewHostname(String arg1);
    public A withNewHostname(StringBuilder arg1);
    public A withNewHostname(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildUrl instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public URL getUrl();
    public URL buildUrl();
    public A withUrl(URL url);
    public Boolean hasUrl();
    public AddressableFluent.UrlNested<A> withNewUrl();
    public AddressableFluent.UrlNested<A> withNewUrlLike(URL item);
    public AddressableFluent.UrlNested<A> editUrl();
    public AddressableFluent.UrlNested<A> editOrNewUrl();
    public AddressableFluent.UrlNested<A> editOrNewUrlLike(URL item);

    public interface UrlNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,URLFluent<AddressableFluent.UrlNested<N>>{

        
    public N and();    public N endUrl();
}


}
